==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/sblock/rlink.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

unset($VAR,$rt);
settype($CONF['rlink_nums'], "integer");
$VAR['Content'] = "";
if ($CONF['rlink_source']==0) { /* get random link from T_Random_Link table */

   $sql = "SELECT id,title FROM T_Random_Link " .
          "ORDER BY RAND() LIMIT $CONF[rlink_nums]";

   $rt = SqlQuery($sql);
   if (mysql_num_rows($rt)) {
      while ($A = mysql_fetch_array($rt)) {
         $VAR['Content'] .= "$CONF[dotchar]".
                          "<a href=\"$CONF[G_URL]/redirect.php?what=rlink&amp;id=$A[id]".
                          "&amp;code=". KWL_HcodeMake("rlink".$A['id'],1) ."\"".
                          " target=\"_blank\">". KWL_PrepareHtml($A['title']) .
                          "</a><BR>\n";
      }
      $VAR['Display'] =& $align;
      if (empty($CONF['rlink_title'])) $VAR['Heading'] = _RANDOM_LINK;
      else $VAR['Heading'] = $CONF['rlink_title'];
      KWL_DrawBlock($VAR);
   }

} elseif ($CONF['rlink_source']==1) { /* get random link from T_Links table */

   $sql = "SELECT Rid,Name,Url FROM T_Links " .
          "ORDER BY RAND() LIMIT $CONF[rlink_nums]";
   $rt = SqlQuery($sql);
   if (mysql_num_rows($rt)) {
      while ($A = mysql_fetch_array($rt)) {
         $url = urlencode($A['Url']);
         $VAR['Content'] .= "$CONF[dotchar]".
                          "<a href=\"$CONF[G_URL]/portal.php?url=$url&what=T_Links&rid=$A[Rid]&code=". KWL_HcodeMake("T_Links".$A['Rid'],1) ."\" target=\"_blank\">". KWL_PrepareHtml($A['Name']) ."</a><BR>\n";
      }
      $VAR['Display'] =& $align;
      if (empty($CONF['rlink_title'])) $VAR['Heading'] = _RANDOM_LINK;
      else $VAR['Heading'] = $CONF['rlink_title'];
      KWL_DrawBlock($VAR);
   }

} elseif ($CONF['rlink_source']==2) { 
   /* 
      get random link from T_IndexLinks table,
      and title from Story.
   */

   $sql = "SELECT Rid,ParentRid,URL FROM T_IndexLinks ".
          "WHERE URL <> '' ORDER BY RAND() LIMIT $CONF[rlink_nums]";
   $rt = SqlQuery($sql);
    if (mysql_num_rows($rt)) {
      while ($A = mysql_fetch_array($rt)) {
         $title = SqlResult("SELECT Heading FROM T_Stories WHERE Rid = '$A[ParentRid]'");
         $url = urlencode($A['URL']);
         $VAR['Content'] .= "$CONF[dotchar]".
                          "<a href=\"$CONF[G_URL]/portal.php?url=$url&what=T_IndexLinks&rid=$A[Rid]&code=". KWL_HcodeMake("T_IndexLinks".$A['Rid'],1) ."\" target=\"_blank\">". KWL_StringCut($title,23) ."...</a><BR>\n";
      }
      $VAR['Display'] =& $align;
      if (empty($CONF['rlink_title'])) $VAR['Heading'] = _RANDOM_LINK;
      else $VAR['Heading'] = $CONF['rlink_title'];
      KWL_DrawBlock($VAR);
   }
  
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/sblock/rlink.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

unset($VAR,$rt);
settype($CONF['rlink_nums'], "integer");
$VAR['Content'] = "";
if ($CONF['rlink_source']==0) { /* get random link from T_Random_Link table */

   $sql = "SELECT id,title FROM T_Random_Link " .
          "ORDER BY RAND() LIMIT $CONF[rlink_nums]";

   $rt = SqlQuery($sql);
   if (mysql_num_rows($rt)) {
      while ($A = mysql_fetch_array($rt)) {
         $VAR['Content'] .= "$CONF[dotchar]".
                          "<a href=\"$CONF[G_URL]/redirect.php?what=rlink&amp;id=$A[id]".
                          "&amp;code=". KWL_HcodeMake("rlink".$A['id'],1) ."\"".
                          " target=\"_blank\">". KWL_PrepareHtml($A['title']) .
                          "</a><br />\n";
      }
      $VAR['Display'] =& $align;
      if (empty($CONF['rlink_title'])) $VAR['Heading'] = _RANDOM_LINK;
      else $VAR['Heading'] = $CONF['rlink_title'];
      KWL_DrawBlock($VAR);
   }

} elseif ($CONF['rlink_source']==1) { /* get random link from T_Links table */

   $sql = "SELECT Rid,Name,Url FROM T_Links " .
          "ORDER BY RAND() LIMIT $CONF[rlink_nums]";
   $rt = SqlQuery($sql);
   if (mysql_num_rows($rt)) {
      while ($A = mysql_fetch_array($rt)) {
         $url = urlencode($A['Url']);
         $VAR['Content'] .= "$CONF[dotchar]".
                          "<a href=\"$CONF[G_URL]/portal.php?url=$url&what=T_Links&rid=$A[Rid]&code=". KWL_HcodeMake("T_Links".$A['Rid'],1) ."\" target=\"_blank\">". KWL_PrepareHtml($A['Name']) ."</a><br />\n";
      }
      $VAR['Display'] =& $align;
      if (empty($CONF['rlink_title'])) $VAR['Heading'] = _RANDOM_LINK;
      else $VAR['Heading'] = $CONF['rlink_title'];
      KWL_DrawBlock($VAR);
   }

} elseif ($CONF['rlink_source']==2) { 
   /* 
      get random link from T_IndexLinks table,
      and title from Story.
   */

   $sql = "SELECT Rid,ParentRid,URL FROM T_IndexLinks ".
          "WHERE URL <> '' ORDER BY RAND() LIMIT $CONF[rlink_nums]";
   $rt = SqlQuery($sql);
    if (mysql_num_rows($rt)) {
      while ($A = mysql_fetch_array($rt)) {
         $title = SqlResult("SELECT Heading FROM T_Stories WHERE Rid = '$A[ParentRid]'");
         $url = urlencode($A['URL']);
         $VAR['Content'] .= "$CONF[dotchar]".
                          "<a href=\"$CONF[G_URL]/portal.php?url=$url&what=T_IndexLinks&rid=$A[Rid]&code=". KWL_HcodeMake("T_IndexLinks".$A['Rid'],1) ."\" target=\"_blank\">". KWL_StringCut($title,23) ."...</a><br />\n";
      }
      $VAR['Display'] =& $align;
      if (empty($CONF['rlink_title'])) $VAR['Heading'] = _RANDOM_LINK;
      else $VAR['Heading'] = $CONF['rlink_title'];
      KWL_DrawBlock($VAR);
   }
  
}
?>
